@@ -1,5 +1,5 @@
 W.Gen <-
-function(X,k,c=0.5){
+function(X,k,c.poly=0.5){
 #k-terms used in GLP similarity calculation, integer value
 #q-quantile for determining sigma in gauss distance
 
@@ -7,7 +7,7 @@ function(X,k,c=0.5){
 ###LP Transform of data
   Tmat<-apply(X,2,FUN="LPT",k=k)
   R<-apcluster::linKernel(Tmat,normalize=TRUE)   #polynomial kernel
-  W<-as.matrix((c+R)^2)
+  W<-as.matrix((c.poly+R)^2)
   diag(W)<-0
   
  #output both similarity matrix W and LPT matrix Tmat
